tw2.slideymenu
==============

:Author: Ralph Bean <ralph.bean@gmail.com>

.. comment: split here

.. _toscawidgets2 (tw2): http://toscawidgets.org/documentation/tw2.core/
.. _jQuery UI: http://jqueryui.com/
.. _jQuery: http://jquery.com/
.. _filament group: http://www.filamentgroup.com/

tw2.slideymenu is a `toscawidgets2 (tw2)`_ package with `slidey` menu that I
made just for you!

Live Demo
---------

Slideymenu is best demonstrated by its use in `narcissus
<http://narcissus.rc.rit.edu>`_.  Definitely check it out.

You can also see it in the `tw2 WidgetBrowser
<http://craftsman.rc.rit.edu/module?module=tw2.slideymenu>`_ although it doesn't
do it justice.

Links
-----
Get the `source from github <http://github.com/ralphbean/tw2.slideymenu>`_.

`PyPI page <http://pypi.python.org/pypi/tw2.slideymenu>`_
and `bugs <http://github.com/ralphbean/tw2.slideymenu/issues/>`_

Description
-----------

`toscawidgets2 (tw2)`_ aims to be a practical and useful widgets framework
that helps people build interactive websites with compelling features, faster
and easier. Widgets are re-usable web components that can include a template,
server-side code and JavaScripts/CSS resources. The library aims to be:
flexible, reliable, documented, performant, and as simple as possible.

This package contains a menu that slides!
